/**
 * Matches various white space characters, including tab, vertical tab, form
 * feed, and zero-width non-breaking space.
 *
 * Unicode space separators are not included!
 */
export declare const WhiteSpace: RegExp;
/**
 * Ensure that the string doesn't start with any of the prohibited characters,
 * including space characters, U+0000 NULL, U+0022 QUOTATION MARK
 * (""), U+0027 APOSTROPHE ("'"), U+003E GREATER-THAN SIGN (>),
 * U+002F SOLIDUS (/), U+003D EQUALS SIGN (=), control characters
 * (U+0000 to U+001F, U+007F to U+009F), and characters that are not
 * defined by Unicode. Following by one or more characters that are not in
 * the prohibited set of characters.
 *
 * @see [HTML syntax attributes](https://www.w3.org/TR/2011/WD-html5-20110525/syntax.html#syntax-attributes)
 */
export declare const AttributeName: RegExp;
export declare const AttributeShorthand: RegExp;
/**
 * Matches boolean literals, allowing for optional single or double quotes.
 */
export declare const BooleanLiteral: RegExp;
/**
 * Matches various forms of numeric literals, including hexadecimal, octal,
 * binary, decimal, and scientific notation.
 */
export declare const NumericLiteral: RegExp;
/**
 * Matches a single-quoted attribute value enclosed in single quotes. Allows
 * for escaped single quotes (`\'`) and escaped newlines (`\\n`), with the
 * additional restriction that the value cannot contain an ambiguous
 * ampersand.
 *
 * @see [HTML syntax attributes](https://www.w3.org/TR/2011/WD-html5-20110525/syntax.html#syntax-attributes)
 * @see [Ambiguous ampersand](https://www.w3.org/TR/2011/WD-html5-20110525/syntax.html#syntax-ambiguous-ampersand).
 */
export declare const SingleQuotedLiteral: RegExp;
/**
 * Matches a double-quoted attribute value enclosed in double quotes. Allows
 * for escaped double quotes (`\"`) and escaped newlines (`\\n`), with the
 * additional restriction that the value cannot contain an ambiguous
 * ampersand.
 *
 * @see [HTML syntax attributes](https://www.w3.org/TR/2011/WD-html5-20110525/syntax.html#syntax-attributes)
 * @see [Ambiguous ampersand](https://www.w3.org/TR/2011/WD-html5-20110525/syntax.html#syntax-ambiguous-ampersand)
 */
export declare const DoubleQuotedLiteral: RegExp;
/**
 * Matches a sequence of characters that must not contain any of the
 * characters U+0022 ("), U+0027 ('), U+0060 (`), U+003D (=), U+003C (<),
 * U+003E (>), or whitespace (space or tab).
 *
 * @see [HTML syntax attributes](https://www.w3.org/TR/2011/WD-html5-20110525/syntax.html#syntax-attributes)
 */
export declare const UnquotedLiteral: RegExp;
